@@ -15,7 +15,7 @@
 #
 # Authors:
 # - Vincent Garonne <vincent.garonne@cern.ch>, 2012-2018
-# - Thomas Beermann <thomas.beermann@cern.ch>, 2012-2018
+# - Thomas Beermann <thomas.beermann@cern.ch>, 2012-2021
 # - Mario Lassnig <mario.lassnig@cern.ch>, 2012-2020
 # - Cedric Serfon <cedric.serfon@cern.ch>, 2013-2021
 # - Ralph Vigne <ralph.vigne@cern.ch>, 2013
@@ -33,7 +33,7 @@
 # - Patrick Austin <patrick.austin@stfc.ac.uk>, 2020
 # - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020-2021
 
-from __future__ import print_function
+from __future__ import absolute_import, print_function
 
 try:
     import importlib
@@ -45,7 +45,6 @@ import base64
 import copy
 import datetime
 import errno
-import functools
 import getpass
 import hashlib
 import json
@@ -61,8 +60,6 @@ import threading
 import time
 import zlib
 from enum import Enum
-from logging import getLogger, Formatter  # NOQA: F401
-from logging.handlers import RotatingFileHandler
 from uuid import uuid4 as uuid
 from xml.etree import ElementTree
 
@@ -520,16 +517,6 @@ def my_key_generator(namespace, fn, **kw):
     return generate_key
 
 
-def get_logger(name):
-    logger = logging.getLogger(name)
-    hdlr = RotatingFileHandler('%s/%s.log' % (config_get('common', 'logdir'), name), maxBytes=1000000000, backupCount=10)
-    formatter = logging.Formatter('%(asctime)s\t%(process)d\t%(levelname)s\t%(message)s')
-    hdlr.setFormatter(formatter)
-    logger.addHandler(hdlr)
-    logger.setLevel(config_get('common', 'loglevel').upper())
-    return logger
-
-
 def construct_surl_DQ2(dsn, filename):
     """
     Defines relative SURL for new replicas. This method
@@ -1431,7 +1418,7 @@ class retry:
         '''
         self.func, self.args, self.kwargs = func, args, kwargs
 
-    def __call__(self, mtries=3, logger=None):
+    def __call__(self, mtries=3, logger=logging.log):
         '''
         :param mtries: maximum number of attempts to execute the function
         :param logger: preferred logger
@@ -1440,27 +1427,11 @@ class retry:
         while attempt > 1:
             try:
                 if logger:
-                    logger.debug('{}: Attempt {}'.format(self.func.__name__, mtries - attempt + 1))
+                    logger(logging.DEBUG, '{}: Attempt {}'.format(self.func.__name__, mtries - attempt + 1))
                 return self.func(*self.args, **self.kwargs)
             except Exception as e:
                 if logger:
-                    logger.debug('{}: Attempt failed {}'.format(self.func.__name__, mtries - attempt + 1))
-                    logger.debug(str(e))
+                    logger(logging.DEBUG, '{}: Attempt failed {}'.format(self.func.__name__, mtries - attempt + 1))
+                    logger(logging.DEBUG, str(e))
                 attempt -= 1
         return self.func(*self.args, **self.kwargs)
-
-
-def formatted_logger(innerfunc, formatstr="%s"):
-    """
-    Decorates the passed function, formatting log input by
-    the passed formatstr. The format string must always include a %s.
-
-    :param innerfunc: function to be decorated. Must take (level, msg) arguments.
-    :type innerfunc: Callable
-    :param formatstr: format string with %s as placeholder.
-    :type formatstr: str
-    """
-    @functools.wraps(innerfunc)
-    def log_format(level, msg, *args, **kwargs):
-        return innerfunc(level, formatstr % msg, *args, **kwargs)
-    return log_format
